==> e2fsprogs-1.41.9-i486-1sys.tgz: usr/doc/e2fsprogs-1.41.9/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
#config /usr/etc/mke2fs.conf   # .new
if [ -x /usr/bin/install-info ]; then
  install-info --info-dir=/usr/info /usr/info/libext2fs.info.gz 2> /dev/null
fi

cp -f /etc/mke2fs.conf /etc/mke2fs.conf.old 
rm /etc/mke2fs.conf
ln -s /usr/etc/mke2fs.conf   /etc/mke2fs.conf


( cd /usr/sbin ; rm -rf mkfs.ext2 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext2 )
( cd /usr/sbin ; rm -rf mkfs.ext3 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext3 )
( cd /usr/sbin ; rm -rf mkfs.ext4 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext4 )
( cd /usr/sbin ; rm -rf mkfs.ext4dev )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext4dev )
( cd /usr/sbin ; rm -rf mkfs.ext5 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext5 )

( cd /sbin ; rm -rf fsck )
( cd /sbin ; ln -sf /usr/sbin/fsck fsck )

( cd /usr/sbin ; rm -rf fsck.ext3 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext3 )
( cd /usr/sbin ; rm -rf fsck.ext4 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext4 )
( cd /usr/sbin ; rm -rf fsck.ext4dev )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext4dev )
( cd /usr/sbin ; rm -rf fsck.ext5 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext5 )


( cd /usr/sbin ; rm -rf findfs )
( cd /usr/sbin ; ln -sf tune2fs findfs )
( cd /usr/sbin ; rm -rf e2label )
( cd /usr/sbin ; ln -sf tune2fs e2label )

#

==> e2fsprogs-1.41.14-i486-1sys.tgz: usr/doc/e2fsprogs-1.41.14/doinst.sh <==
#!/bin/sh
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

cp -f /etc/mke2fs.conf /etc/mke2fs.conf.old 
config /etc/mke2fs.conf.new


rm /usr/etc/mke2fs.conf
ln -s /etc/mke2fs.conf   /usr/etc/mke2fs.conf


if [ -x /usr/bin/install-info ]; then
  install-info --info-dir=/usr/info /usr/info/libext2fs.info.gz 2> /dev/null
fi


( cd /usr/sbin ; rm -rf mkfs.ext2 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext2 )
( cd /usr/sbin ; rm -rf mkfs.ext3 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext3 )
( cd /usr/sbin ; rm -rf mkfs.ext4 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext4 )
( cd /usr/sbin ; rm -rf mkfs.ext4dev )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext4dev )
( cd /usr/sbin ; rm -rf mkfs.ext5 )
( cd /usr/sbin ; ln -sf mke2fs mkfs.ext5 )

( cd /sbin ; rm -rf fsck )
( cd /sbin ; ln -sf /usr/sbin/fsck fsck )

( cd /usr/sbin ; rm -rf fsck.ext3 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext3 )
( cd /usr/sbin ; rm -rf fsck.ext4 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext4 )
( cd /usr/sbin ; rm -rf fsck.ext4dev )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext4dev )
( cd /usr/sbin ; rm -rf fsck.ext5 )
( cd /usr/sbin ; ln -sf fsck.ext2 fsck.ext5 )


( cd /usr/sbin ; rm -rf findfs )
( cd /usr/sbin ; ln -sf tune2fs findfs )
( cd /usr/sbin ; rm -rf e2label )
( cd /usr/sbin ; ln -sf tune2fs e2label )

#
